@@ -36,18 +36,18 @@ setup_plate <- function(plate, type) {
 init_plate <- function(plate) {
   stopifnot(plate %>% inherits("ddpcr_plate"))
   step_begin(sprintf("Initializing plate of type `%s`", type(plate)))
-  
+
   plate %<>%
     set_default_clusters %>%
     set_default_steps %>%
     init_data %>%
     init_meta
-  
+
   status(plate) <- step(plate, 'INITIALIZE')
   plate[['version']] <- as.character(utils::packageVersion("ddpcr"))
   plate[['dirty']] <- FALSE
   step_end()
-  
+
   plate
 }
 
@@ -55,16 +55,16 @@ init_plate <- function(plate) {
 init_data <- function(plate) {
   x_var <- x_var(plate)
   y_var <- y_var(plate)
-  
+
   new_plate_data <- plate_data(plate)
+  new_plate_data <- dplyr::select(new_plate_data, 1:3)
   colnames(new_plate_data) <- c("well", x_var, y_var)
-  new_plate_data <- dplyr::select_(new_plate_data, "well", x_var, y_var)
   new_plate_data[['cluster']] <- cluster(plate, 'UNDEFINED')
   new_plate_data[[x_var]] <- as.integer(new_plate_data[[x_var]])
   new_plate_data[[y_var]] <- as.integer(new_plate_data[[y_var]])
   new_plate_data <- dplyr::arrange_(new_plate_data, ~ well)
   plate_data(plate) <- new_plate_data
-  
+
   plate
 }
 
@@ -72,19 +72,19 @@ init_data <- function(plate) {
 init_meta <- function(plate) {
   plate_data <- plate_data(plate)
   plate_meta <- plate_meta(plate)
-  
+
   # read the meta data file (we only care about the well -> sample mapping)
   if (is.null(plate_meta)) {
     plate_meta <- DEFAULT_PLATE_META
   } else {
     meta_cols_keep <- c("well", "sample", "target_ch1", "target_ch2")
     tryCatch({
-      
-      if (colnames(plate_meta)[5] == 'typeassay' | 
+
+      if (colnames(plate_meta)[5] == 'typeassay' |
           colnames(plate_meta)[5] == 'targettype'){
         # different versions of QuantaSoft
         if (colnames(plate_meta)[5] == 'typeassay'){
-          plate_meta %<>% dplyr::mutate_("target" = ~assay, 
+          plate_meta %<>% dplyr::mutate_("target" = ~assay,
                                         "channel" = ~substr(typeassay, 1,3))
         }
         else{
@@ -98,8 +98,8 @@ init_meta <- function(plate) {
           ) %>%
           dplyr::ungroup()
       }
-      
-      
+
+
       plate_meta %<>%
         dplyr::select_(~ dplyr::one_of(meta_cols_keep)) %>%
         merge_dfs_overwrite_col(DEFAULT_PLATE_META, .,
@@ -110,7 +110,7 @@ init_meta <- function(plate) {
       err_msg("the metadata file is invalid")
     })
   }
-  
+
   # populate the metadata with some initial variables
   wells_used <- plate_data[['well']] %>% unique
   plate_meta[['used']] <- plate_meta[['well']] %in% wells_used
@@ -121,7 +121,7 @@ init_meta <- function(plate) {
     dplyr::summarise_("drops" = ~ n()) %>%
     dplyr::left_join(plate_meta, ., by = "well") %>%
     arrange_meta
-  
+
   plate_meta(plate) <- plate_meta
   plate
 }
@@ -134,11 +134,11 @@ set_plate_type <- function(plate, type) {
   if (!missing(type) && is.null(type) && class(plate) != "list") {
     return(plate)
   }
-  
+
   if (missing(type) || is.null(type) || !nzchar(type)) {
     type <- NULL
-  }  
-  
+  }
+
   # Add the given type to the classlist (initially the class will be "list"
   # because that's the mode of a plate - we want to exclude that one)
   new_class <- type
@@ -146,7 +146,7 @@ set_plate_type <- function(plate, type) {
     new_class <- c(class(plate), new_class)
   }
   class(plate) <- new_class
-  
+
   # Recursively add the plate type of the parent
   set_plate_type(plate,
                  structure(plate, class = type) %>% parent_plate_type)
@@ -162,4 +162,4 @@ set_default_clusters <- function(plate) {
 set_default_steps <- function(plate) {
   steps(plate) <- define_steps(plate)
   plate
-}
\ No newline at end of file
+}
